# notepasser

## video demo
https://youtu.be/G_Q85QDvGYc

## update 2
added GUI, improved the code quality a lot, fixed lots of bugs

## what is it
a library allowing you to discover and send encrypted messages to people on your same network.

## features
- discover users on the same network
- send encrypted messages (NOT mitm resistant in the slightest)
- connect across different clients
- (future) have a preset rotating token which resets together at the start of each session
- gracefully connect and disconnect

## installation
- run `pip install notepasser`

## quick start
- TUI client by running cli/cli_peer.py
- GUI client by running ui/main.py

## ai notice for siege
- main script used lots of help from ai but the core is written by myself completely (still holds very true)
- this week's update written without ai